@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 import sys
 sys.path.append(sys.path[0] + "/../lib/python")
@@ -8,20 +8,17 @@ import os
 import shutil
 import tempfile
 
-try:
-    from urllib.request import urlopen
-    from urllib.error import HTTPError
-except ImportError:
-    from urllib2 import urlopen, HTTPError
+from urllib.request import urlopen
+from urllib.error import HTTPError
 
 from debian_linux.abi import Symbols
 from debian_linux.config import *
 from debian_linux.debian import *
 
-default_url_base = "http://ftp.de.debian.org/debian/"
-default_url_base_incoming = "http://incoming.debian.org/"
-default_url_base_ports = "http://ftp.debian-ports.org/debian/"
-default_url_base_security = "http://security.debian.org/"
+default_url_base = "http://deb.debian.org/debian/"
+default_url_base_incoming = "http://incoming.debian.org/debian-buildd/"
+default_url_base_ports = "http://ftp.ports.debian.org/debian-ports/"
+default_url_base_ports_incoming = "http://incoming.ports.debian.org/"
 
 
 class url_debian_flat(object):
@@ -47,11 +44,6 @@ class url_debian_ports_pool(url_debian_pool):
         return self.base + "pool-" + arch + "/main/" + source[0] + "/" + source + "/" + filename
 
 
-class url_debian_security_pool(url_debian_pool):
-    def __call__(self, source, filename, arch):
-        return self.base + "pool/updates/main/" + source[0] + "/" + source + "/" + filename
-
-
 class Main(object):
     dir = None
 
@@ -168,9 +160,6 @@ class Main(object):
     def update_flavour(self, config, arch, featureset, flavour):
         config_base = config.merge('base', arch, featureset, flavour)
 
-        if not config_base.get('modules', True):
-            return
-
         self.log("Updating ABI for arch %s, featureset %s, flavour %s: " % (arch, featureset, flavour))
         try:
             if featureset == 'none':
@@ -193,11 +182,10 @@ if __name__ == '__main__':
     options.add_option("-i", "--incoming", action="store_true", dest="incoming")
     options.add_option("--incoming-config", action="store_true", dest="incoming_config")
     options.add_option("--ports", action="store_true", dest="ports")
-    options.add_option("--security", action="store_true", dest="security")
     options.add_option("-u", "--url-base", dest="url_base", default=default_url_base)
     options.add_option("--url-base-incoming", dest="url_base_incoming", default=default_url_base_incoming)
     options.add_option("--url-base-ports", dest="url_base_ports", default=default_url_base_ports)
-    options.add_option("--url-base-security", dest="url_base_security", default=default_url_base_security)
+    options.add_option("--url-base-ports-incoming", dest="url_base_ports_incoming", default=default_url_base_ports_incoming)
 
     opts, args = options.parse_args()
 
@@ -210,20 +198,16 @@ if __name__ == '__main__':
         kw['flavour'] = args[2]
 
     url_base = url_debian_pool(opts.url_base)
-    url_base_incoming = url_debian_flat(opts.url_base_incoming)
+    url_base_incoming = url_debian_pool(opts.url_base_incoming)
     url_base_ports = url_debian_ports_pool(opts.url_base_ports)
-    url_base_security = url_debian_security_pool(opts.url_base_security)
+    url_base_ports_incoming = url_debian_flat(opts.url_base_ports_incoming)
     if opts.incoming_config:
         url = url_config = url_base_incoming
     else:
         url_config = url_base
-        if opts.security:
-            url = url_base_security
-        elif opts.incoming:
-            url = url_base_incoming
-        elif opts.ports:
-            url = url_base_ports
+        if opts.ports:
+            url = url_base_ports_incoming if opts.incoming else url_base_ports
         else:
-            url = url_base
+            url = url_base_incoming if opts.incoming else url_base
 
     Main(url, url_config, **kw)()
